@@ -21,7 +21,7 @@ Version 0.01
 
 =cut
 
-our $VERSION = '2.38';
+our $VERSION = '2.39';
 
 =head1 SYNOPSIS
 
@@ -136,67 +136,71 @@ sub parse_file_mce{
     my $fh = IO::File->new( $self->infile, q{<} ) or $self->log->fatal("Error opening file  ".$self->infile."  ".$!);
     die unless $fh;
 
-    my $cmd;
     while(<$fh>){
         my $line = $_;
         next unless $line;
         next unless $line =~ m/\S/;
-        next if $line =~ m/^#/;
-
-        if($self->has_cmd){
-            $DB::single=2;
-            $self->add_cmd($line);
-            if($line =~ m/\\$/){
-                next;
-            }
-            else{
-                $self->log->info("Enqueuing command:\n".$self->cmd);
-                #MCE
-                $self->queue->enqueue($self->counter, $self->cmd);
-                #Threads
-#                $self->run_command_threads;
-                $self->clear_cmd;
-                $self->inc_counter;
-            }
-        }
-        else{
-            $DB::single=2;
-            $self->cmd($line);
-            if($line =~ m/\\$/){
-                next;
-            }
-            elsif( $self->match_cmd(qr/^wait$/) ){
-                $DB::single=2;
-                $self->log->info("Beginning command:\n".$self->cmd);
-                $self->log->info("Waiting for all children to complete...");
-                $self->clear_cmd;
-                #MCE
-
-                $self->wait(1);
-                push(@{$self->jobref}, []);
-                $self->queue->enqueue((undef) x ($self->procs * 2));
-                $self->mce->run(0);  # 0 indicates do not shutdown after running
-
-#                #THREADS
-#                $self->threads->wait_all_children;
-                $self->log->info("All children have completed processing!");
-            }
-            else{
-                $self->log->info("Enqueuing command:\n".$self->cmd);
-                $DB::single=2;
-                #MCE
-                $self->queue->enqueue($self->counter, $self->cmd);
-#                #Threads
-#                $self->run_command_threads;
-                $self->clear_cmd;
-                $self->inc_counter;
-            }
-        }
+        $self->process_lines($line);
         $self->wait(0);
     }
 
     $DB::single=2;
+}
 
+sub process_lines{
+    my $self = shift;
+    my $line = shift;
+
+    return if $line =~ m/^#/;
+    if($self->has_cmd){
+        $DB::single=2;
+        $self->add_cmd($line);
+        if($line =~ m/\\$/){
+            return;
+        }
+        else{
+            $self->log->info("Enqueuing command:\n".$self->cmd);
+            #MCE
+            $self->queue->enqueue($self->counter, $self->cmd);
+            #Threads
+            #                $self->run_command_threads;
+            $self->clear_cmd;
+            $self->inc_counter;
+        }
+    }
+    else{
+        $DB::single=2;
+        $self->cmd($line);
+        if($line =~ m/\\$/){
+            next;
+        }
+        elsif( $self->match_cmd(qr/^wait$/) ){
+            $DB::single=2;
+            $self->log->info("Beginning command:\n".$self->cmd);
+            $self->log->info("Waiting for all children to complete...");
+            $self->clear_cmd;
+            #MCE
+
+            $self->wait(1);
+            push(@{$self->jobref}, []);
+            $self->queue->enqueue((undef) x ($self->procs * 2));
+            $self->mce->run(0);  # 0 indicates do not shutdown after running
+
+            #                #THREADS
+            #                $self->threads->wait_all_children;
+            $self->log->info("All children have completed processing!");
+        }
+        else{
+            $self->log->info("Enqueuing command:\n".$self->cmd);
+            $DB::single=2;
+            #MCE
+            $self->queue->enqueue($self->counter, $self->cmd);
+            #                #Threads
+            #                $self->run_command_threads;
+            $self->clear_cmd;
+            $self->inc_counter;
+        }
+    }
 }
 
 #use namespace::autoclean;
